@@ -936,3 +936,6 @@ SELECT test.Unknown FROM test
 SELECT lock
 SELECT a FROM test GROUP BY GROUPING SETS ((x + y, z))
 SELECT (LEAD(foo1, 1, 0)) OVER (PARTITION BY foo2 ORDER BY foo3) FROM t
+SELECT LAST_VALUE(CASE WHEN interval <> 'foo' THEN interval END) IGNORE NULLS FROM t
+WITH UNNEST AS (SELECT 1 AS UNNEST) SELECT UNNEST FROM UNNEST
+SELECT * FROM tbl GROUP BY GROUPING SETS ((a, b), c, CUBE (a, b), ROLLUP (c, d), (a + y, b * 1), ())
\ No newline at end of file
