@@ -1535,6 +1535,14 @@ STRUCT<str_col STRING>;
 -- Snowflake
 --------------------------------------
 
+# dialect: snowflake
+ABS(tbl.bigint_col);
+BIGINT;
+
+# dialect: snowflake
+ABS(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 AI_AGG('foo', 'bar');
 VARCHAR;
@@ -1623,6 +1631,10 @@ VARCHAR;
 COLLATE('hello', 'utf8');
 VARCHAR;
 
+# dialect: snowflake
+COSH(1.5);
+DOUBLE;
+
 # dialect: snowflake
 COMPRESS('Hello World', 'SNAPPY');
 BINARY;
@@ -1631,6 +1643,14 @@ BINARY;
 COMPRESS('Hello World', 'zlib(1)');
 BINARY;
 
+# dialect: snowflake
+DEGREES(PI()/3);
+DOUBLE;
+
+# dialect: snowflake
+DEGREES(1);
+DOUBLE;
+
 # dialect: snowflake
 DECOMPRESS_BINARY('compressed_data', 'SNAPPY');
 BINARY;
@@ -1639,6 +1659,22 @@ BINARY;
 DECOMPRESS_STRING('compressed_data', 'ZSTD');
 VARCHAR;
 
+# dialect: snowflake
+DIV0(10, 0);
+DOUBLE;
+
+# dialect: snowflake
+DIV0(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+DIV0NULL(10, 0);
+DOUBLE;
+
+# dialect: snowflake
+DIV0NULL(tbl.double_col, tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 LPAD('Hello', 10, '*');
 VARCHAR;
@@ -1667,6 +1703,14 @@ BINARY;
 COLLATION('hello');
 VARCHAR;
 
+# dialect: snowflake
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+COS(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 CONCAT('Hello', 'World!');
 VARCHAR;
@@ -1715,6 +1759,14 @@ INT;
 EDITDISTANCE('hello', 'world', 3);
 INT;
 
+# dialect: snowflake
+EXP(1);
+DOUBLE;
+
+# dialect: snowflake
+EXP(5.5);
+DOUBLE;
+
 # dialect: snowflake
 ENDSWITH('hello world', 'world');
 BOOLEAN;
@@ -1883,6 +1935,54 @@ BOOLEAN;
 REGEXP_LIKE('foo', NULL, 'baz');
 BOOLEAN;
 
+# dialect: snowflake
+REGEXP_COUNT('hello world', 'l');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_COUNT('hello world', 'l', 1);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_COUNT('hello world', 'l', 1, 'i');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1, 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1, 1, 'i');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1, 1, 'i', 0);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world', 1, 1, 0);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world', 1, 1, 0, 'i');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world', 1, 1, 0, 'i', 1);
+DECIMAL(38, 0);
+
 # dialect: snowflake
 REGEXP_REPLACE('hello world', 'world', 'universe');
 VARCHAR;
@@ -1915,6 +2015,26 @@ VARCHAR;
 REGEXP_SUBSTR('hello world', 'world', 1, 1, 'e', NULL);
 VARCHAR;
 
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1, 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1, 1, 'i');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1, 1, 'i', 0);
+ARRAY;
+
 # dialect: snowflake
 REPEAT('hello', 3);
 VARCHAR;
@@ -2067,6 +2187,22 @@ VARCHAR;
 SHA2_HEX('foo', null);
 VARCHAR;
 
+# dialect: snowflake
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+SIGN(tbl.double_col);
+INT;
+
+# dialect: snowflake
+SOUNDEX(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+SOUNDEX_P123('test');
+VARCHAR;
+
 # dialect: snowflake
 SPACE(5);
 VARCHAR;
@@ -2079,6 +2215,10 @@ VARCHAR;
 SPACE(NULL);
 VARCHAR;
 
+# dialect: snowflake
+SQRT(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 SPLIT('hello world', ' ');
 ARRAY;
@@ -2091,6 +2231,22 @@ ARRAY;
 SPLIT(NULL, ',');
 ARRAY;
 
+# dialect: snowflake
+SPLIT_PART('11.22.33', '.', 1);
+VARCHAR;
+
+# dialect: snowflake
+STRTOK('hello world');
+VARCHAR;
+
+# dialect: snowflake
+STRTOK('hello world', ' ');
+VARCHAR;
+
+# dialect: snowflake
+STRTOK('a.b.c', '.', 1);
+VARCHAR;
+
 # dialect: snowflake
 STARTSWITH('hello world', 'hello');
 BOOLEAN;
@@ -2107,6 +2263,30 @@ BOOLEAN;
 STARTSWITH(tbl.bin_col, NULL);
 BOOLEAN;
 
+# dialect: snowflake
+SEARCH(line, 'king');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH((play, line), 'dream');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH(line, 'king', ANALYZER => 'UNICODE_ANALYZER');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH(line, 'king', SEARCH_MODE => 'OR');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH(line, 'king', ANALYZER => 'UNICODE_ANALYZER', SEARCH_MODE => 'AND');
+BOOLEAN;
+
+# dialect: snowflake
+STRTOK_TO_ARRAY('a,b,c', ',');
+ARRAY;
+
 # dialect: snowflake
 SUBSTR('hello world', 1, 5);
 VARCHAR;
@@ -2123,6 +2303,18 @@ BINARY;
 SUBSTR(tbl.str_col, NULL);
 STRING;
 
+# dialect: snowflake
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+TRANSLATE('hello world', 'elo', 'XYZ');
+VARCHAR;
+
+# dialect: snowflake
+UNICODE('€');
+INT;
+
 # dialect: snowflake
 TRIM('hello world');
 VARCHAR;
@@ -2143,6 +2335,30 @@ VARCHAR;
 TRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+TRY_BASE64_DECODE_BINARY('SGVsbG8=');
+BINARY;
+
+# dialect: snowflake
+TRY_BASE64_DECODE_BINARY('SGVsbG8=', 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+BINARY;
+
+# dialect: snowflake
+TRY_BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=');
+VARCHAR;
+
+# dialect: snowflake
+TRY_BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=', 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+VARCHAR;
+
+# dialect: snowflake
+TRY_HEX_DECODE_BINARY('48656C6C6F');
+BINARY;
+
+# dialect: snowflake
+TRY_HEX_DECODE_STRING('48656C6C6F');
+VARCHAR;
+
 # dialect: snowflake
 UPPER('Hello, world!');
 VARCHAR;
