@@ -472,17 +472,22 @@ FROM (
       alias_1.id = alias_2.id
     )
 ) AS main_query;
+WITH "alias_2" AS (
+  SELECT
+    "company_table_2"."id" AS "id"
+  FROM "company_table" AS "company_table_2"
+  LEFT JOIN "unlocked" AS "unlocked"
+    ON "company_table_2"."id" = "unlocked"."company_id"
+  WHERE
+    CASE WHEN "unlocked"."company_id" IS NULL THEN 0 ELSE 1 END = FALSE
+    AND NOT "company_table_2"."id" IS NULL
+)
 SELECT
   "company_table"."id" AS "id",
   "company_table"."score" AS "score"
 FROM "company_table" AS "company_table"
-JOIN "company_table" AS "company_table_2"
-  ON "company_table"."id" = "company_table_2"."id"
-LEFT JOIN "unlocked" AS "unlocked"
-  ON "company_table_2"."id" = "unlocked"."company_id"
-WHERE
-  CASE WHEN "unlocked"."company_id" IS NULL THEN 0 ELSE 1 END = FALSE
-  AND NOT "company_table_2"."id" IS NULL;
+JOIN "alias_2" AS "alias_2"
+  ON "alias_2"."id" = "company_table"."id";
 
 # title: db.table alias clash
 # execute: false
@@ -531,7 +536,10 @@ FROM "unioned" AS "unioned"
 WHERE
   "unioned"."source_system" = 'bamboohr' OR "unioned"."source_system" = 'workday'
 QUALIFY
-  ROW_NUMBER() OVER (PARTITION BY "unioned"."unique_filter_key" ORDER BY "unioned"."sort_order" DESC, 1) = 1;
+  ROW_NUMBER() OVER (
+    PARTITION BY "unioned"."unique_filter_key"
+    ORDER BY "unioned"."sort_order" DESC, 1
+  ) = 1;
 
 # title: pivoted source with explicit selections
 # execute: false
@@ -547,7 +555,8 @@ FROM (
     "tb"."b" AS "b",
     "tb"."c" AS "c"
   FROM "sc"."tb" AS "tb"
-) AS "_q_0" PIVOT(SUM("_q_0"."c") FOR "_q_0"."b" IN ('x', 'y', 'z')) AS "_q_1";
+) AS "_q_0"
+PIVOT(SUM("_q_0"."c") FOR "_q_0"."b" IN ('x', 'y', 'z')) AS "_q_1";
 
 # title: pivoted source with explicit selections where one of them is excluded & selected at the same time
 # note: we need to respect the exclude when selecting * from pivoted source and not include the computed column twice
@@ -564,7 +573,8 @@ FROM (
     "tb"."b" AS "b",
     "tb"."c" AS "c"
   FROM "sc"."tb" AS "tb"
-) AS "_q_0" PIVOT(SUM("_q_0"."c") FOR "_q_0"."b" IN ('x', 'y', 'z')) AS "_q_1";
+) AS "_q_0"
+PIVOT(SUM("_q_0"."c") FOR "_q_0"."b" IN ('x', 'y', 'z')) AS "_q_1";
 
 # title: pivoted source with implicit selections
 # execute: false
@@ -579,7 +589,8 @@ FROM (
     "u"."g" AS "g",
     "u"."h" AS "h"
   FROM "u" AS "u"
-) AS "_q_0" PIVOT(SUM("_q_0"."f") FOR "_q_0"."h" IN ('x', 'y')) AS "_q_1";
+) AS "_q_0"
+PIVOT(SUM("_q_0"."f") FOR "_q_0"."h" IN ('x', 'y')) AS "_q_1";
 
 # title: selecting explicit qualified columns from pivoted source with explicit selections
 # execute: false
@@ -592,7 +603,8 @@ FROM (
     "u"."f" AS "f",
     "u"."h" AS "h"
   FROM "u" AS "u"
-) AS "_q_0" PIVOT(SUM("_q_0"."f") FOR "_q_0"."h" IN ('x', 'y')) AS "piv";
+) AS "_q_0"
+PIVOT(SUM("_q_0"."f") FOR "_q_0"."h" IN ('x', 'y')) AS "piv";
 
 # title: selecting explicit unqualified columns from pivoted source with implicit selections
 # execute: false
@@ -600,7 +612,8 @@ SELECT x, y FROM u PIVOT (SUM(f) FOR h IN ('x', 'y'));
 SELECT
   "_q_0"."x" AS "x",
   "_q_0"."y" AS "y"
-FROM "u" AS "u" PIVOT(SUM("u"."f") FOR "u"."h" IN ('x', 'y')) AS "_q_0";
+FROM "u" AS "u"
+PIVOT(SUM("u"."f") FOR "u"."h" IN ('x', 'y')) AS "_q_0";
 
 # title: selecting all columns from a pivoted CTE source, using alias for the aggregation and generating bigquery
 # execute: false
@@ -617,17 +630,19 @@ SELECT
   `_q_0`.`g` AS `g`,
   `_q_0`.`sum_x` AS `sum_x`,
   `_q_0`.`sum_y` AS `sum_y`
-FROM `u_cte` AS `u_cte` PIVOT(SUM(`u_cte`.`f`) AS `sum` FOR `u_cte`.`h` IN ('x', 'y')) AS `_q_0`;
+FROM `u_cte` AS `u_cte`
+PIVOT(SUM(`u_cte`.`f`) AS `sum` FOR `u_cte`.`h` IN ('x', 'y')) AS `_q_0`;
 
 # title: selecting all columns from a pivoted source and generating snowflake
 # execute: false
 # dialect: snowflake
 SELECT * FROM u PIVOT (SUM(f) FOR h IN ('x', 'y'));
 SELECT
-  "_q_0"."G" AS "G",
-  "_q_0"."'x'" AS "'x'",
-  "_q_0"."'y'" AS "'y'"
-FROM "U" AS "U" PIVOT(SUM("U"."F") FOR "U"."H" IN ('x', 'y')) AS "_q_0";
+  "_Q_0"."G" AS "G",
+  "_Q_0"."'x'" AS "'x'",
+  "_Q_0"."'y'" AS "'y'"
+FROM "U" AS "U"
+PIVOT(SUM("U"."F") FOR "U"."H" IN ('x', 'y')) AS "_Q_0";
 
 # title: selecting all columns from a pivoted source and generating spark
 # note: spark doesn't allow pivot aliases or qualified columns for the pivot's "field" (`h`)
@@ -641,7 +656,8 @@ SELECT
 FROM (
   SELECT
     *
-  FROM `u` AS `u` PIVOT(SUM(`u`.`f`) FOR `h` IN ('x', 'y'))
+  FROM `u` AS `u`
+  PIVOT(SUM(`u`.`f`) FOR `h` IN ('x', 'y'))
 ) AS `_q_0`;
 
 # title: selecting all columns from a pivoted source, pivot has column aliases
@@ -674,20 +690,22 @@ WITH "SOURCE" AS (
 SELECT
   "FINAL"."ID" AS "ID",
   "FINAL"."TIMESTAMP_1" AS "TIMESTAMP_1"
-FROM "SOURCE" AS "SOURCE" PIVOT(MAX("SOURCE"."VALUE") FOR "SOURCE"."KEY" IN ('a', 'b', 'c')) AS "FINAL"("ID", "TIMESTAMP_1", "TIMESTAMP_2", "COL_1", "COL_2", "COL_3");
+FROM "SOURCE" AS "SOURCE"
+PIVOT(MAX("SOURCE"."VALUE") FOR "SOURCE"."KEY" IN ('a', 'b', 'c')) AS "FINAL"("ID", "TIMESTAMP_1", "TIMESTAMP_2", "COL_1", "COL_2", "COL_3");
 
 # title: unpivoted table source with a single value column, unpivot columns can't be qualified
 # execute: false
 # dialect: snowflake
 SELECT * FROM m_sales AS m_sales(empid, dept, jan, feb) UNPIVOT(sales FOR month IN (jan, feb)) ORDER BY empid;
 SELECT
-  "_q_0"."EMPID" AS "EMPID",
-  "_q_0"."DEPT" AS "DEPT",
-  "_q_0"."MONTH" AS "MONTH",
-  "_q_0"."SALES" AS "SALES"
-FROM "M_SALES" AS "M_SALES"("EMPID", "DEPT", "JAN", "FEB") UNPIVOT("SALES" FOR "MONTH" IN ("JAN", "FEB")) AS "_q_0"
+  "M_SALES"."EMPID" AS "EMPID",
+  "M_SALES"."DEPT" AS "DEPT",
+  "M_SALES"."MONTH" AS "MONTH",
+  "M_SALES"."SALES" AS "SALES"
+FROM "M_SALES" AS "M_SALES"("EMPID", "DEPT", "JAN", "FEB")
+UNPIVOT("SALES" FOR "MONTH" IN ("JAN", "FEB")) AS "M_SALES"
 ORDER BY
-  "_q_0"."EMPID";
+  "M_SALES"."EMPID";
 
 # title: unpivoted table source, unpivot has column aliases
 # execute: false
@@ -704,17 +722,18 @@ FROM (
     "m_sales"."jan" AS "jan",
     "m_sales"."feb" AS "feb"
   FROM "m_sales" AS "m_sales"
-) AS "m_sales" UNPIVOT("sales" FOR "month" IN ("m_sales"."jan", "m_sales"."feb")) AS "unpiv"("a", "b", "c", "d");
+) AS "m_sales"
+UNPIVOT("sales" FOR "month" IN ("m_sales"."jan", "m_sales"."feb")) AS "unpiv"("a", "b", "c", "d");
 
 # title: unpivoted derived table source with a single value column
 # execute: false
 # dialect: snowflake
 SELECT * FROM (SELECT * FROM m_sales) AS m_sales(empid, dept, jan, feb) UNPIVOT(sales FOR month IN (jan, feb)) ORDER BY empid;
 SELECT
-  "_q_0"."EMPID" AS "EMPID",
-  "_q_0"."DEPT" AS "DEPT",
-  "_q_0"."MONTH" AS "MONTH",
-  "_q_0"."SALES" AS "SALES"
+  "_Q_0"."EMPID" AS "EMPID",
+  "_Q_0"."DEPT" AS "DEPT",
+  "_Q_0"."MONTH" AS "MONTH",
+  "_Q_0"."SALES" AS "SALES"
 FROM (
   SELECT
     "M_SALES"."EMPID" AS "EMPID",
@@ -722,31 +741,39 @@ FROM (
     "M_SALES"."JAN" AS "JAN",
     "M_SALES"."FEB" AS "FEB"
   FROM "M_SALES" AS "M_SALES"
-) AS "M_SALES" UNPIVOT("SALES" FOR "MONTH" IN ("JAN", "FEB")) AS "_q_0"
+) AS "M_SALES"
+UNPIVOT("SALES" FOR "MONTH" IN ("JAN", "FEB")) AS "_Q_0"
 ORDER BY
-  "_q_0"."EMPID";
+  "_Q_0"."EMPID";
 
 # title: unpivoted table source with a single value column, unpivot columns can be qualified
 # execute: false
 # dialect: bigquery
-# note: the named columns aren't supported by BQ but we add them here to avoid defining a schema
+# note: the named columns aren not supported by BQ but we add them here to avoid defining a schema
 SELECT * FROM produce AS produce(product, q1, q2, q3, q4) UNPIVOT(sales FOR quarter IN (q1, q2, q3, q4));
 SELECT
-  `_q_0`.`product` AS `product`,
-  `_q_0`.`quarter` AS `quarter`,
-  `_q_0`.`sales` AS `sales`
-FROM `produce` AS `produce` UNPIVOT(`sales` FOR `quarter` IN (`produce`.`q1`, `produce`.`q2`, `produce`.`q3`, `produce`.`q4`)) AS `_q_0`;
+  `produce`.`product` AS `product`,
+  `produce`.`quarter` AS `quarter`,
+  `produce`.`sales` AS `sales`
+FROM `produce` AS `produce`
+UNPIVOT(`sales` FOR `quarter` IN (`produce`.`q1`, `produce`.`q2`, `produce`.`q3`, `produce`.`q4`)) AS `produce`;
 
 # title: unpivoted table source with multiple value columns
 # execute: false
 # dialect: bigquery
 SELECT * FROM produce AS produce(product, q1, q2, q3, q4) UNPIVOT((first_half_sales, second_half_sales) FOR semesters IN ((Q1, Q2) AS 'semester_1', (Q3, Q4) AS 'semester_2'));
 SELECT
-  `_q_0`.`product` AS `product`,
-  `_q_0`.`semesters` AS `semesters`,
-  `_q_0`.`first_half_sales` AS `first_half_sales`,
-  `_q_0`.`second_half_sales` AS `second_half_sales`
-FROM `produce` AS `produce` UNPIVOT((`first_half_sales`, `second_half_sales`) FOR `semesters` IN ((`produce`.`q1`, `produce`.`q2`) AS 'semester_1', (`produce`.`q3`, `produce`.`q4`) AS 'semester_2')) AS `_q_0`;
+  `produce`.`product` AS `product`,
+  `produce`.`semesters` AS `semesters`,
+  `produce`.`first_half_sales` AS `first_half_sales`,
+  `produce`.`second_half_sales` AS `second_half_sales`
+FROM `produce` AS `produce`
+UNPIVOT((`first_half_sales`, `second_half_sales`) FOR 
+  `semesters` IN (
+    (`produce`.`q1`, `produce`.`q2`) AS 'semester_1',
+    (`produce`.`q3`, `produce`.`q4`) AS 'semester_2'
+  )
+) AS `produce`;
 
 # title: quoting is preserved
 # dialect: snowflake
@@ -818,13 +845,13 @@ WHERE
 GROUP BY `dAy`, `top_term`, rank
 ORDER BY `DaY` DESC;
 SELECT
-  `TOp_TeRmS`.`refresh_date` AS `day`,
-  `TOp_TeRmS`.`term` AS `top_term`,
-  `TOp_TeRmS`.`rank` AS `rank`
-FROM `bigquery-public-data.GooGle_tReNDs.TOp_TeRmS` AS `TOp_TeRmS`
+  `top_terms`.`refresh_date` AS `day`,
+  `top_terms`.`term` AS `top_term`,
+  `top_terms`.`rank` AS `rank`
+FROM `bigquery-public-data.GooGle_tReNDs.TOp_TeRmS` AS `top_terms`
 WHERE
-  `TOp_TeRmS`.`rank` = 1
-  AND CAST(`TOp_TeRmS`.`refresh_date` AS DATE) >= DATE_SUB(CURRENT_DATE, INTERVAL 2 WEEK)
+  `top_terms`.`rank` = 1
+  AND `top_terms`.`refresh_date` >= DATE_SUB(CURRENT_DATE, INTERVAL '2' WEEK)
 GROUP BY
   `day`,
   `top_term`,
@@ -1368,7 +1395,13 @@ LEFT JOIN `_u_3` AS `_u_3`
   ON `_u_3`.`_u_4` = `cs1`.`cs_order_number`
 JOIN `call_center` AS `call_center`
   ON `call_center`.`cc_call_center_sk` = `cs1`.`cs_call_center_sk`
-  AND `call_center`.`cc_county` IN ('Williamson County', 'Williamson County', 'Williamson County', 'Williamson County', 'Williamson County')
+  AND `call_center`.`cc_county` IN (
+    'Williamson County',
+    'Williamson County',
+    'Williamson County',
+    'Williamson County',
+    'Williamson County'
+  )
 JOIN `customer_address` AS `customer_address`
   ON `cs1`.`cs_ship_addr_sk` = `customer_address`.`ca_address_sk`
   AND `customer_address`.`ca_state` = 'GA'
@@ -1388,3 +1421,80 @@ WHERE
 ORDER BY
   COUNT(DISTINCT `cs1`.`cs_order_number`)
 LIMIT 100;
+
+# execute: false
+SELECT
+  *
+FROM event
+WHERE priority = 'High' AND tagname IN (
+  SELECT
+    tag_input AS tagname
+  FROM cascade
+  WHERE tag_input = 'XXX' OR tag_output = 'XXX'
+  UNION
+  SELECT
+    tag_output AS tagname
+  FROM cascade
+  WHERE tag_input = 'XXX' OR tag_output = 'XXX'
+);
+WITH "_u_0" AS (
+  SELECT
+    "cascade"."tag_input" AS "tagname"
+  FROM "cascade" AS "cascade"
+  WHERE
+    "cascade"."tag_input" = 'XXX' OR "cascade"."tag_output" = 'XXX'
+  UNION
+  SELECT
+    "cascade"."tag_output" AS "tagname"
+  FROM "cascade" AS "cascade"
+  WHERE
+    "cascade"."tag_input" = 'XXX' OR "cascade"."tag_output" = 'XXX'
+), "_u_1" AS (
+  SELECT
+    "cascade"."tag_input" AS "tagname"
+  FROM "_u_0" AS "_u_0"
+  GROUP BY
+    "cascade"."tag_input"
+)
+SELECT
+  *
+FROM "event" AS "event"
+LEFT JOIN "_u_1" AS "_u_1"
+  ON "_u_1"."tagname" = "event"."tagname"
+WHERE
+  "event"."priority" = 'High' AND NOT "_u_1"."tagname" IS NULL;
+
+# title: SELECT TRANSFORM ... Spark clause when schema is provided
+# execute: false
+# dialect: spark
+WITH a AS (SELECT 'v' AS x) SELECT * FROM (SELECT TRANSFORM(x) USING 'cat' AS (y STRING) FROM a);
+WITH `a` AS (
+  SELECT
+    'v' AS `x`
+), `_q_0` AS (
+  SELECT
+    TRANSFORM(`a`.`x`) USING 'cat' AS (
+      `y` STRING
+    )
+  FROM `a` AS `a`
+)
+SELECT
+  `_q_0`.`y` AS `y`
+FROM `_q_0` AS `_q_0`;
+
+# title: SELECT TRANSFORM ... Spark clause when schema is not provided
+# execute: false
+# dialect: spark
+WITH a AS (SELECT 'v' AS x) SELECT * FROM (SELECT TRANSFORM(x) USING 'cat'  FROM a);
+WITH `a` AS (
+  SELECT
+    'v' AS `x`
+), `_q_0` AS (
+  SELECT
+    TRANSFORM(`a`.`x`) USING 'cat'
+  FROM `a` AS `a`
+)
+SELECT
+  `_q_0`.`key` AS `key`,
+  `_q_0`.`value` AS `value`
+FROM `_q_0` AS `_q_0`;
